"""
Version information for NetworkX, created during installation.

Do not add this file to the repository.

"""

import datetime

version = '2.1'
date = 'Sun Mar 25 16:44:01 2018'

# Was NetworkX built from a development version? If so, remember that the major
# and minor versions reference the "target" (rather than "current") release.
dev = False

# Format: (name, major, min, revision)
version_info = ('networkx', '2', '1', None)

# Format: a 'datetime.datetime' instance
date_info = datetime.datetime(2018, 3, 25, 16, 44, 1)

# Format: (vcs, vcs_tuple)
vcs_info = (None, (None, None))

